use strict;
use warnings;
package Dist::Zilla::Plugin::SigStore::UploadToCPAN;
our $VERSION = '0.01'; # VERSION
# ABSTRACT: upload a sigstore bundle to CPAN

use Moose;
extends 'Dist::Zilla::Plugin::UploadToCPAN';

use namespace::autoclean;



sub upload_to_cpan {
  my ($self, $archive) = @_;
  $self->before_release;
  $self->uploader->upload_file("$archive");
  return;
}

__PACKAGE__->meta->make_immutable;
1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::Plugin::SigStore::UploadToCPAN - upload a sigstore bundle to CPAN

=head1 VERSION

version 0.01

=head1 DESCRIPTION

Extends L<Dist::Zilla::Plugin::UploadToCPAN> to allow uploading an
arbitrary file (such as a sigstore bundle) rather than the release
archive itself.

=head1 METHODS

=head2 upload_to_cpan($filename)

Internal function to upload to PAUSE

=head1 ACKNOWLEDGEMENTS

Based on L<Dist::Zilla::Plugin::UploadToCPAN> by Ricardo SIGNES
and contributors.

=head1 AUTHOR

Timothy Legge <timlegge@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Timothy Legge <timlegge@gmail.com>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
